(function($) {
    "use strict";
    // Custom scripts

    $(document).ready(function(){

        var siteLoaded = false,
            deviceDesktop = true;

        if (isMobile.tablet || isMobile.phone ) {
            $('body .inview').removeClass('inview');
            deviceDesktop = false;
        } else {
            $('body').addClass('desktop');
        }
        /*End checking device type*/


        /*Begin Window Resize*/
        function windowResize() {
            var height = $(window).height();
            $('.window-height').css('height', height+'px');
        }

        if (deviceDesktop===false) { //fix height: 100vh on some mobile browsers
            $(window).resize(function(){
                windowResize();
            });
        }
        /*End Window Resize*/

        /*Begin on window scroll*/
        $(window).scroll(function() {
            if (deviceDesktop) {
                $("body .inview:in-viewport").each(function() {
                    var timeout = parseInt($(this).data('inview-timeout'),10) || 10;
                    var inview = $(this)
                    setTimeout(function() {
                        inview.show().addClass('animated ' + inview.data('inview-animation') );
                        inview.removeClass('inview');
                    }, timeout);
                });
            }

            //animate skills
            if (!!siteLoaded) {
                $("body .fact-percent-inview:in-viewport").each(function() {
                    var percent = parseInt($(this).data('fact-percent'),10) || 0,
                        valueElement = $(this).find('.fact-percent-value'),
                        currentValue = 0;

                    var increment = function() {
                        currentValue++;
                        valueElement.html( currentValue + '%');
                        if (currentValue < percent) {
                            setTimeout(function() { increment(); },30);
                        }
                    };

                    if (currentValue < percent) {
                        setTimeout(function() { increment(); },30);
                    }

                    $(this).removeClass('fact-percent-inview');
                });


                $('body.desktop .section-title-inview:in-viewport').each(function() {
                    var title = [];
                    title.push( $(this).text() );

                    $(this).css('min-height', $(this).height() ).html('').typed({
                        strings: title,
                        typeSpeed: 50, // typing speed
                        backSpeed: 0, // backspacing speed
                        startDelay: 100, // time before typing starts
                        backDelay: 3000, // pause before backspacing
                        loop: false, // loop on or off (true or false)
                        loopCount: false, // number of loops, false = infinite
                        showCursor: false,
                        attr: null, // attribute to type, null = text for everything except inputs, which default to placeholder
                        callback: function(){ } // call function after typing is done
                    });

                    $(this).removeClass('section-title-inview');
                });
            }

        });
        /*End on window scroll*/

        /*Begin Show/Hide Menu*/
        $('#menu-btn, #menu-close-btn').on('click',function(event) {
            event.preventDefault();
            $('body').toggleClass('show-menu');
        });

        $('#main-nav').find('li a').on('click', function(event) {
            $('body').toggleClass('show-menu');
        });
        /*End Show/Hide Menu*/

        /*Begin smooth scrolling*/
        $('#main-nav li a, #home-buttons a').on('click', function(event) {
            event.preventDefault();
            var href = $(this).attr('href');
            if ( href.indexOf('#')===0 ) { //it's internal link
                var target = $(href);
                if (target.length) {// and it's ID exists
                    $(window).scrollTo( target.offset().top, 200 );
                }
            } else {
                window.location = href; // external link
            }
        });
        /*End smooth scrolling*/


        /*Begin Portfolio colorbox*/
        $('.zoom').each(function() {
            $(this).colorbox({rel: $(this).data('rel'), fixed: true, maxWidth: "80%", maxHeight: "80%"});
        });
        $('.zoom-details').each(function() {
            $(this).colorbox({html: $(this).parents('.portfolio-item').find('.item-details').html(), fixed: true, maxWidth: "80%", maxHeight: "80%"});
        });
        /*End Portfolio colorbox*/

        /*Begin Portfolio Filtering */
        $('#portfolio-filters .filter').on('click', function(event) {
            event.preventDefault();

            $(this).addClass('active').siblings().removeClass('active')

            var section = $(this).parents('#portfolio'),
                filter = $(this).attr('data-filter'),
                allItems = section.find('.portfolio-item'),
                targetItems = section.find(filter);

            allItems.removeClass('bounceIn animated filtered');

            if (deviceDesktop) { /*Animations only on desktop*/
                targetItems.addClass('bounceIn');
            }

            targetItems.addClass('animated');

            allItems.filter(':not(.animated)').addClass('filtered');

        });
        /*End  Portfolio Filtering*/



        /*Begin carousel*/
        $('.carousel').carousel({
            interval: 5000
        });
        /*End carousel*/


        /*Begin Contact Form*/
        var contactFormElem = jQuery("#contact-form");
        if (!!contactFormElem) {
            contactFormElem.submit(function(e)
            {
                var postData = contactFormElem.serializeArray();

                var formURL = window.location.href;
                formURL = formURL.substring(0,formURL.lastIndexOf('/')+1);

                formURL = formURL + contactFormElem.attr("action");

                jQuery.ajax(
                    {
                        url : formURL,
                        type: "POST",
                        data : postData,
                        success:function(data, textStatus, jqXHR)
                        {
                            contactFormElem.find('input[type=text], textarea').val('');
                            jQuery("#contact-form-response").html('<div class="alert box-half-space"><span class="fa fa-thumbs-up fa-fw"></span>Thank you for your message.</div>');
                            jQuery.scrollTo('#contact-form-response');
                        },
                        error: function(jqXHR, textStatus, errorThrown)
                        {
                            jQuery("#contact-form-response").html('<div class="alert box-half-space"><span class="fa fa-exclamation-circle fa-fw"></span>Connection error occurred. Message not sent.</div>');
                            jQuery.scrollTo('#contact-form-response');
                        }
                    });
                e.preventDefault(); //STOP default action
            });
        }
        /*End Contact Form*/


        /*Begin Change page after site load */
        var afterLoad = function() {

            siteLoaded = true;

            var homeSubtitles = [];

            if (deviceDesktop===false) {
                windowResize(); //fix height: 100vh on some mobile browsers
            } else {
                $('[data-toggle="tooltip"]').tooltip(); //pin boostrap tooltips
            }

            $(window).trigger('scroll');

            $('#menu').mCustomScrollbar({theme:"minimal"});

            /* Begin Typing animation */
            $('body.desktop #home-subtitle').children('span').each(function() {
                homeSubtitles.push( $(this).html() );
            });
            if (homeSubtitles.length>1) { //do not animate unless there is more than one item
                $('#home-subtitle').html('').typed({
                    strings: homeSubtitles,
                    typeSpeed: 50, // typing speed
                    backSpeed: 0, // backspacing speed
                    startDelay: 400, // time before typing starts
                    backDelay: 3000, // pause before backspacing
                    loop: true, // loop on or off (true or false)
                    loopCount: false, // number of loops, false = infinite
                    showCursor: true,
                    attr: null, // attribute to type, null = text for everything except inputs, which default to placeholder
                    callback: function(){ } // call function after typing is done
                });
            }
            /* End Typing animation */

        };
        Pace.on('hide', afterLoad);
        /*End Change page after site load */


    });   /* ---- DOCUMENT READY END ---- */

})(jQuery);
